package com.usky.iot.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.iot.domain.BaseGgpFacility;
import com.usky.iot.mapper.BaseGgpFacilityMapper;
import com.usky.iot.service.BaseGgpFacilityService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.iot.service.vo.BaseGgpFacilityRequest;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * <p>
 * 地理信息 服务实现类
 * </p>
 *
 * @author han
 * @since 2023-06-02
 */
@Service
public class BaseGgpFacilityServiceImpl extends AbstractCrudService<BaseGgpFacilityMapper, BaseGgpFacility> implements BaseGgpFacilityService {
    @Override
    public boolean add(BaseGgpFacility baseGgpFacility) {
        baseGgpFacility.setCreator(SecurityUtils.getUsername());
        baseGgpFacility.setCreateTime(LocalDateTime.now());
        return this.save(baseGgpFacility);
    }

    @Override
    public void update(BaseGgpFacility baseGgpFacility) {
        baseGgpFacility.setUpdateTime(LocalDateTime.now());
        baseGgpFacility.setUpdatePerson(SecurityUtils.getUsername());
        this.updateById(baseGgpFacility);
    }

    @Override
    public CommonPage<BaseGgpFacility> page(BaseGgpFacilityRequest piRequest) {
        IPage<BaseGgpFacility> page = new Page<>(piRequest.getCurrent(), piRequest.getSize());
        LambdaQueryWrapper<BaseGgpFacility> lambdaQuery = Wrappers.lambdaQuery();
        lambdaQuery
                .like(StringUtils.isNotBlank(piRequest.getFacilityName()),BaseGgpFacility::getFacilityName,
                        piRequest.getFacilityName())
                .eq(StringUtils.isNotBlank(piRequest.getFacilityNum()),BaseGgpFacility::getFacilityNum,piRequest.getFacilityNum())
                .eq(null != piRequest.getId(),BaseGgpFacility::getId,piRequest.getId());
        page = this.page(page,lambdaQuery);
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    public boolean remove(Integer id) {
        return this.removeById(id);
    }
}
